import numpy as np
import pandas as pd


def get_data_type(data):
    data_type = type(data)
    if data_type == type([[]]):
        return "list"
    elif data_type == type({}):
        return "dict"
    elif data_type == type(pd.DataFrame()):
        return "dataFrame"
    elif data_type == type(np.array([])):
        return "numpy"
    elif data_type == type(""):
        return "string"
    else:
        return "other"


def list_to_numpy(data):
    result = []
    for i in range(len(data)):
        result.append(np.array(data[i]))
    return np.array(result)


def list_to_dict(data):
    data = list_to_numpy(data)
    result = {}
    # 设置列名
    head = data[0]
    data = np.delete(data, 0, 0)
    for i in range(len(head)):
        result[str(head[i])] = data[:, i]
    return result


def dict_to_dataframe(data):
    return pd.DataFrame(data)


def list_to_dataframe(data):
    data = list_to_dict(data)
    return dict_to_dataframe(data)


def numpy_to_dataframe(data):
    return pd.DataFrame(data)


def csv_to_dataframe(data):
    return pd.read_csv(data)


def excel_to_dataframe(data):
    return pd.read_excel(data)


def change_type_to_dataframe(data, data_type):
    result = pd.DataFrame()
    if data_type == "list":
        result = list_to_dataframe(data)
    elif data_type == "dict":
        result = dict_to_dataframe(data)
    elif data_type == "dataFrame":
        result = data
    elif data_type == "numpy":
        result = numpy_to_dataframe(data)
    elif data_type == "string":
        if data.endswith(".csv"):
            result = csv_to_dataframe(data)
        elif data.endswith(".xlsx"):
            result = excel_to_dataframe(data)
    return result



#!/usr/bin/env python
from os import path
from setuptools import setup, find_packages

here = path.abspath(path.dirname(__file__))
with open(path.join(here, 'requirements.txt'), 'r', encoding='utf-8') as f:
    all_reqs = f.read().split('\n')

with open(path.join(here, 'README.md'), 'r', encoding='utf-8') as f:
    long_description = f.read()

install_requires = [x.strip() for x in all_reqs if 'git+' not in x]

setup(
    name='dw-feature-tool',  # 必填，项目的名字，用户根据这个名字安装，pip install SpiderKeeper-new
    version='1.0.0',  # 必填，项目的版本，建议遵循语义化版本规范
    author='yanghy',  # 项目的作者
    description='feature-tool',  # 项目的一个简短描述
    long_description=long_description,  # 项目的详细说明，通常读取 README.md 文件的内容
    long_description_content_type='text/markdown',  # 描述的格式，可选的值： text/plain, text/x-rst, and text/markdown
    author_email='784166768@qq.com',  # 作者的有效邮箱地址
    url='https://github.com/Dawaner/FeatureTool',  # 项目的源码地址
    license='MIT',
    include_package_data=True,
    package_data= {
        'src' : ["resources/"]
    },
    packages=find_packages(),  # 必填，指定打包的目录，默认是当前目录，如果是其他目录比如 src, 可以使用 find_packages(where='src')
    install_requires=install_requires,  # 指定你的项目依赖的 python 包，这里直接读取 requirements.txt
    # 分类器通过对项目进行分类，帮助用户找到项目
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
    ],
    python_requires=">=3.8"
)
